@@ -64,7 +64,7 @@ class HttpMethod(object):
     - https://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html
     - https://datatracker.ietf.org/doc/html/rfc7231
     - https://en.wikipedia.org/wiki/Hypertext_Transfer_Protocol#Request_methods
-    https://developer.mozilla.org/en-US/docs/Web/HTTP/Methods
+    - https://developer.mozilla.org/en-US/docs/Web/HTTP/Methods
     """
 
     CONNECT = "CONNECT"  # HTTP/1.1
