@@ -35,7 +35,7 @@ from cardinal_pythonlib.sqlalchemy.dialect import (
 
 if TYPE_CHECKING:
     from sqlalchemy.engine.base import Engine
-    from sqlalchemy.engine.result import ResultProxy
+    from sqlalchemy.engine import Result
 
 
 # =============================================================================
@@ -104,7 +104,7 @@ def get_sqlserver_product_version(engine: "Engine") -> Tuple[int]:
         "instances."
     )
     sql = "SELECT CAST(SERVERPROPERTY('ProductVersion') AS VARCHAR)"
-    rp = engine.execute(sql)  # type: ResultProxy
+    rp = engine.execute(sql)  # type: Result
     row = rp.fetchone()
     dotted_version = row[0]  # type: str  # e.g. '12.0.5203.0'
     return tuple(int(x) for x in dotted_version.split("."))
